import styles from "./styles.module.css";
import Image from "next/image";
import Link from "next/link";
import Icons from "../icons";
import PropTypes from "prop-types";

const Card = ({
  title,
  description,
  image,
  publishedDate,
  authorName,
  images,
  readingTime,
}) => {
  return (
    <div className={styles.card}>
      <Link href="#">
        <Image className={styles.img} src={image.url} alt={title} />
      </Link>
      <div className={styles["card-content"]}>
        <Link href="#" className={styles.title}>
          <p>{title}</p>
        </Link>
        <p className={styles.description}>{description}</p>
        <div className={styles.authorcontainer}>
          <div className={styles.cardbottom}>
            <Image className={styles.img} src={images.url} alt={authorName} />
            <div className={styles.authordescription}>
              <p>{authorName}</p>
              <div className={styles["author-desc"]}>
                {publishedDate}
                <span className={styles.icon}>
                  <Icons name="clock" size="small" />
                  {readingTime}
                </span>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};
Card.propTypes = {
  title: PropTypes.string,
  description: PropTypes.string,
  image: PropTypes.shape({
    url: PropTypes.string,
  }),
  publishedDate: PropTypes.string,
  authorName: PropTypes.string,
  images: PropTypes.shape({
    url: PropTypes.string, // Use PropTypes.string for images
  }),

  readingTime: PropTypes.string,
};

export default Card;
